[![License: MIT](https://img.shields.io/badge/license-MIT-C06524)](https://github.com/YehudaElyasaf/stucknet/blob/master/LICENSE)
[![PyPI - Version](https://img.shields.io/pypi/v/stucknet.svg)](https://pypi.org/project/stucknet/)

TODO: continue README
